# flake8: noqa

from typing import TYPE_CHECKING

# non-runtime imports for type hints

if TYPE_CHECKING:
    from openapi_client.api.accounts_api import AccountsApi
    from openapi_client.api.campaigns_api import CampaignsApi
    from openapi_client.api.catalogs_api import CatalogsApi
    from openapi_client.api.coupons_api import CouponsApi
    from openapi_client.api.data_privacy_api import DataPrivacyApi
    from openapi_client.api.events_api import EventsApi
    from openapi_client.api.flows_api import FlowsApi
    from openapi_client.api.forms_api import FormsApi
    from openapi_client.api.images_api import ImagesApi
    from openapi_client.api.lists_api import ListsApi
    from openapi_client.api.metrics_api import MetricsApi
    from openapi_client.api.profiles_api import ProfilesApi
    from openapi_client.api.reporting_api import ReportingApi
    from openapi_client.api.reviews_api import ReviewsApi
    from openapi_client.api.segments_api import SegmentsApi
    from openapi_client.api.tags_api import TagsApi
    from openapi_client.api.templates_api import TemplatesApi
    from openapi_client.api.tracking_settings_api import TrackingSettingsApi
    from openapi_client.api.web_feeds_api import WebFeedsApi
    from openapi_client.api.webhooks_api import WebhooksApi
    


# lazily import apis into api package (see https://docs.python.org/3/reference/datamodel.html#customizing-module-attribute-access)

object_origins = {
    # import apis into sdk package
    "AccountsApi": "openapi_client.api.accounts_api",
    "CampaignsApi": "openapi_client.api.campaigns_api",
    "CatalogsApi": "openapi_client.api.catalogs_api",
    "CouponsApi": "openapi_client.api.coupons_api",
    "DataPrivacyApi": "openapi_client.api.data_privacy_api",
    "EventsApi": "openapi_client.api.events_api",
    "FlowsApi": "openapi_client.api.flows_api",
    "FormsApi": "openapi_client.api.forms_api",
    "ImagesApi": "openapi_client.api.images_api",
    "ListsApi": "openapi_client.api.lists_api",
    "MetricsApi": "openapi_client.api.metrics_api",
    "ProfilesApi": "openapi_client.api.profiles_api",
    "ReportingApi": "openapi_client.api.reporting_api",
    "ReviewsApi": "openapi_client.api.reviews_api",
    "SegmentsApi": "openapi_client.api.segments_api",
    "TagsApi": "openapi_client.api.tags_api",
    "TemplatesApi": "openapi_client.api.templates_api",
    "TrackingSettingsApi": "openapi_client.api.tracking_settings_api",
    "WebFeedsApi": "openapi_client.api.web_feeds_api",
    "WebhooksApi": "openapi_client.api.webhooks_api",
    
}

def __getattr__(name):
    if name in object_origins:
        module = __import__(object_origins[name], None, None, [name])
        return getattr(module, name)
    return __import__(f"openapi_client.api.{name}")



# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class UniversalContentResponseObjectResourceAttributes(BaseModel):
    """
    UniversalContentResponseObjectResourceAttributes
    """ # noqa: E501
    name: Optional[StrictStr] = Field(description="The name for this universal content")
    definition: Optional[Dict[str, Any]] = None
    created: Optional[datetime] = Field(description="The datetime when this universal content was created")
    updated: Optional[datetime] = Field(description="The datetime when this universal content was updated")
    screenshot_status: Optional[StrictStr] = Field(description="The status of a universal content screenshot.")
    screenshot_url: Optional[StrictStr]
    __properties: ClassVar[List[str]] = ["name", "definition", "created", "updated", "screenshot_status", "screenshot_url"]

    @field_validator('screenshot_status')
    def screenshot_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['completed', 'failed', 'generating', 'never_generated', 'not_renderable', 'stale']):
            raise ValueError("must be one of enum values ('completed', 'failed', 'generating', 'never_generated', 'not_renderable', 'stale')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UniversalContentResponseObjectResourceAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if definition (nullable) is None
        # and model_fields_set contains the field
        if self.definition is None and "definition" in self.model_fields_set:
            _dict['definition'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if updated (nullable) is None
        # and model_fields_set contains the field
        if self.updated is None and "updated" in self.model_fields_set:
            _dict['updated'] = None

        # set to None if screenshot_status (nullable) is None
        # and model_fields_set contains the field
        if self.screenshot_status is None and "screenshot_status" in self.model_fields_set:
            _dict['screenshot_status'] = None

        # set to None if screenshot_url (nullable) is None
        # and model_fields_set contains the field
        if self.screenshot_url is None and "screenshot_url" in self.model_fields_set:
            _dict['screenshot_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UniversalContentResponseObjectResourceAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "definition": obj.get("definition"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "screenshot_status": obj.get("screenshot_status"),
            "screenshot_url": obj.get("screenshot_url")
        })
        return _obj





# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.form_version_ab_test import FormVersionABTest
from typing import Optional, Set
from typing_extensions import Self

class FormVersionResponseObjectResourceAttributes(BaseModel):
    """
    FormVersionResponseObjectResourceAttributes
    """ # noqa: E501
    form_type: Optional[StrictStr] = Field(description="The type of form.")
    ab_test: Optional[FormVersionABTest] = None
    status: Optional[StrictStr] = Field(description="Status of the form version. \"live\" means it's live on site.")
    created_at: Optional[datetime] = Field(description="ISO8601 timestamp when the form version was created.")
    updated_at: Optional[datetime] = Field(description="ISO8601 timestamp when the form version was last updated.")
    __properties: ClassVar[List[str]] = ["form_type", "ab_test", "status", "created_at", "updated_at"]

    @field_validator('form_type')
    def form_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['banner', 'embed', 'flyout', 'full_page', 'popup']):
            raise ValueError("must be one of enum values ('banner', 'embed', 'flyout', 'full_page', 'popup')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['draft', 'live']):
            raise ValueError("must be one of enum values ('draft', 'live')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FormVersionResponseObjectResourceAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of ab_test
        if self.ab_test:
            _dict['ab_test'] = self.ab_test.to_dict()
        # set to None if form_type (nullable) is None
        # and model_fields_set contains the field
        if self.form_type is None and "form_type" in self.model_fields_set:
            _dict['form_type'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict['created_at'] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict['updated_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FormVersionResponseObjectResourceAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "form_type": obj.get("form_type"),
            "ab_test": FormVersionABTest.from_dict(obj["ab_test"]) if obj.get("ab_test") is not None else None,
            "status": obj.get("status"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Klaviyo API

    The Klaviyo REST API. Please visit https://developers.klaviyo.com for more details.

    Contact: developers@klaviyo.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from openapi_client.models.send_options import SendOptions
from openapi_client.models.sms_render_options import SMSRenderOptions
from typing import Optional, Set
from typing_extensions import Self

class FlowActionResponseObjectResourceAttributes(BaseModel):
    """
    FlowActionResponseObjectResourceAttributes
    """ # noqa: E501
    action_type: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    created: Optional[datetime] = None
    updated: Optional[datetime] = None
    settings: Optional[Dict[str, Any]] = None
    tracking_options: Optional[Dict[str, Any]] = None
    send_options: Optional[SendOptions] = None
    badge_options: Optional[Dict[str, Any]] = None
    render_options: Optional[SMSRenderOptions] = None
    __properties: ClassVar[List[str]] = ["action_type", "status", "created", "updated", "settings", "tracking_options", "send_options", "badge_options", "render_options"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlowActionResponseObjectResourceAttributes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of send_options
        if self.send_options:
            _dict['send_options'] = self.send_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of render_options
        if self.render_options:
            _dict['render_options'] = self.render_options.to_dict()
        # set to None if action_type (nullable) is None
        # and model_fields_set contains the field
        if self.action_type is None and "action_type" in self.model_fields_set:
            _dict['action_type'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if updated (nullable) is None
        # and model_fields_set contains the field
        if self.updated is None and "updated" in self.model_fields_set:
            _dict['updated'] = None

        # set to None if settings (nullable) is None
        # and model_fields_set contains the field
        if self.settings is None and "settings" in self.model_fields_set:
            _dict['settings'] = None

        # set to None if tracking_options (nullable) is None
        # and model_fields_set contains the field
        if self.tracking_options is None and "tracking_options" in self.model_fields_set:
            _dict['tracking_options'] = None

        # set to None if badge_options (nullable) is None
        # and model_fields_set contains the field
        if self.badge_options is None and "badge_options" in self.model_fields_set:
            _dict['badge_options'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlowActionResponseObjectResourceAttributes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action_type": obj.get("action_type"),
            "status": obj.get("status"),
            "created": obj.get("created"),
            "updated": obj.get("updated"),
            "settings": obj.get("settings"),
            "tracking_options": obj.get("tracking_options"),
            "send_options": SendOptions.from_dict(obj["send_options"]) if obj.get("send_options") is not None else None,
            "badge_options": obj.get("badge_options"),
            "render_options": SMSRenderOptions.from_dict(obj["render_options"]) if obj.get("render_options") is not None else None
        })
        return _obj


